@@ -1,24 +1,22 @@
 #!/usr/bin/perl
 
-use lib qw( lib easydbi-lib );
+use lib qw( lib );
 
-# use this before POE, so Sprocket loads the Epoll loop if we have it
 use Sprocket qw(
     Client
     Server
     Plugin::HTTP::Server
     Plugin::HTTP::Deny
-    Plugin::Manager
 );
 use POE;
 
 my %opts = (
     LogLevel => 4,
     TimeOut => 0,
-    MaxConnections => 32000,
+#    MaxConnections => 10000,
 );
 
-# comet http server
+# http server
 Sprocket::Server->spawn(
     %opts,
     Name => 'HTTP Server',
@@ -41,21 +39,6 @@ Sprocket::Server->spawn(
     ],
 );
 
-# backend server
-Sprocket::Server->spawn(
-    %opts,
-    Name => 'Manager',
-    ListenPort => 5000,
-    ListenAddress => '127.0.0.1',
-    Plugins => [
-        {
-            Plugin => Sprocket::Plugin::Manager->new(),
-            Priority => 0,
-        },
-    ],
-);
-
-
 $poe_kernel->run();
 
 1;
